import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;

public class ImageProcessorTest {

	static String[] images = {"dog1.jpg", "dog2.jpg", "dog3.jpg"};

	public static void process(Photo[] pArray, ImageMode mode) {
		for (Photo p : pArray) {
			process(p, mode);
		}
	}
	
	public static void process(Photo p, ImageMode mode) {
		switch(mode) {
		case CONVERT:
			convert(p, ConvertMode.TO_PNG);
			break;
		case RESIZE:
			resize(p, 200, 200);
			break;
		case ROTATE:
			rotate(p, 125.0f);
			break;
		case GRAYSCALE:
			grayscale(p);
			break;
		default:
			break;
		}
	}
	public static void convert(Photo p, ConvertMode mode) {
		String inputFile = p.getFullPath();
		String outputFile = p.getFullpathWithoutExt() 
				+ "-out." + mode.getName();
		try {
			ImageIO.write(p.getImg(), mode.getName(), new File(outputFile));
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	public static void resize(Photo p, int width, int height) {
		String inputFile = p.getFullPath();
		String outputFile = p.getFullpathWithoutExt() 
				+ "-thumb." + p.getFormat();
		try {
			BufferedImage outputImg = ImageUtil.resize(p.getImg(), width, height); // resize img
			ImageIO.write(outputImg, p.getFormat(), new File(outputFile));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	public static void rotate(Photo p, float angle) {
		String inputFile = p.getFullPath();
		String outputFile = p.getFullpathWithoutExt() 
				+ "-rot." + p.getFormat();
		try {
			BufferedImage outputImg = ImageUtil.rotate(p.getImg(), angle); // rotate img
			ImageIO.write(outputImg, p.getFormat(), new File(outputFile));
		} catch (IOException e) {
			e.printStackTrace();
		}		
	}
	public static void grayscale(Photo p) {
		String inputFile = p.getFullPath();
		String outputFile = p.getFullpathWithoutExt() 
				+ "-gray." + p.getFormat();
		try {
			BufferedImage outputImg = ImageUtil.grayscale(p.getImg()); // grayscale img
			ImageIO.write(outputImg, p.getFormat(), new File(outputFile));
		} catch (IOException e) {
			e.printStackTrace();
		}		
	}
	
	public static void main(String[] args) {

		Photo[] photoArray = new Photo[3];
		for (int i=0; i<3; i++) {
			photoArray[i] = new Photo(images[i]);
			photoArray[i].print();
		}
		
		for (ImageMode mode: ImageMode.values()) {
			process(photoArray, mode);
		}

	}

}
